<?php
require_once('../../../' . $_REQUEST['tenant'] . '/config.php');

if (!isset($_POST['master_report_id']) || !isset($_POST['stage'])) {
    echo json_encode(['success' => false, 'message' => 'Missing required parameters.']);
    exit;
}

$master_report_id = $_POST['master_report_id'];  // Use master_report_id for consistency
$stage = intval($_POST['stage']);  // Stage to clear

// Determine the correct column to clear based on the stage
switch ($stage) {
    case 1:
        $column = 'installation_details';
        break;
    case 2:
        $column = 'schedule_of_inspection';
        break;
    case 3:
        $column = 'condition_schedule';
        break;
    case 4:
        $column = 'circuit_results';
        break;
    default:
        echo json_encode(['success' => false, 'message' => 'Invalid stage.']);
        exit;
}

// Start the database transaction for consistency
$con->begin_transaction();

try {
    // If clearing stages 1-3, update all rows with the same master_report_id
    if ($stage <= 3) {
        $updateQuery = "UPDATE elec_report SET $column = NULL WHERE master_report_id = ?";
        $stmt = $con->prepare($updateQuery);
        $stmt->bind_param("s", $master_report_id);  // Bind the report ID
        $stmt->execute();
        $stmt->close();
    }
    
    // If clearing stage 4, update only the specific board's data (clear circuit_results)
    if ($stage == 4) {
        if (!isset($_POST['board_id']) || empty($_POST['board_id'])) {
            echo json_encode(['success' => false, 'message' => 'Board ID missing for stage 4.']);
            exit;
        }
        $board_id = intval($_POST['board_id']);  // Board to clear

        // Clear data only for the specific board
        $updateQuery = "UPDATE elec_report SET $column = NULL WHERE master_report_id = ? AND board_id = ?";
        $stmt = $con->prepare($updateQuery);
        $stmt->bind_param("si", $master_report_id, $board_id);  // Bind the report and board ID
        $stmt->execute();
        $stmt->close();
    }

    // Also reset the stage status for the specified stage
    $query = "SELECT stage_status FROM elec_report WHERE master_report_id = ?";
    $stmt = $con->prepare($query);
    $stmt->bind_param("s", $master_report_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $reportData = $result->fetch_assoc();
    $stmt->close();

    // Decode stage_status JSON
    $stageStatus = !empty($reportData['stage_status']) ? json_decode($reportData['stage_status'], true) : [];

    // Remove the cleared stage from stage_status (specific to the stage)
    unset($stageStatus[$stage]);

    // Encode and update stage_status
    $stageStatusJson = json_encode($stageStatus);
    $updateStatusQuery = "UPDATE elec_report SET stage_status = ? WHERE master_report_id = ?";
    $updateStatusStmt = $con->prepare($updateStatusQuery);
    $updateStatusStmt->bind_param("ss", $stageStatusJson, $master_report_id);
    $updateStatusStmt->execute();
    $updateStatusStmt->close();

    // Commit the transaction
    $con->commit();

    echo json_encode(['success' => true, 'message' => 'Stage cleared successfully.']);
} catch (Exception $e) {
    // Rollback transaction on error
    $con->rollback();
    echo json_encode(['success' => false, 'message' => 'Failed to clear stage.']);
}

exit;
?>