<?php
// inspection_test_results.php

// Display header note with Circuit Index button
echo '<div class="note note-secondary mb-3"><strong>Inspection and Test Results</strong>
    <span class="float-end">
        <button id="openSidebarBtn" class="btn btn-info" onclick="openSidebar()">
            <i class="fad fa-list me-1"></i> Circuit Index
        </button>
    </span>
</div>';

// Retrieve Existing Report Data
$master_report_id = $_GET['master_report_id'] ?? null;
$board_id         = $_GET['board_id']        ?? null;
if ($master_report_id && $board_id) {
    $query = "SELECT circuit_results, observation_data FROM elec_report WHERE master_report_id = ? AND board_id = ?";
    $stmt = $con->prepare($query);
    $stmt->bind_param("si", $master_report_id, $board_id);
    $stmt->execute();
    $reportData = $stmt->get_result()->fetch_assoc();
    $stmt->close();
}

$circuitData     = !empty($reportData['circuit_results'])
                 ? json_decode($reportData['circuit_results'], true)
                 : [];
$observationData = !empty($reportData['observation_data'])
                 ? json_decode($reportData['observation_data'], true)
                 : [];

// Fetch Circuits and group by numeric prefix
$query = "SELECT circuit_id, circuit_no, circuit_description
            FROM elec_circuit
           WHERE board_id = ?
        ORDER BY circuit_no ASC";
$stmt = $con->prepare($query);
$stmt->bind_param("i", $board_id);
$stmt->execute();
$result = $stmt->get_result();
$groupedCircuits = [];
while ($row = $result->fetch_assoc()) {
    if (preg_match('/^(\d+)/', $row['circuit_no'], $m)) {
        $grp = $m[1];
    } else {
        $grp = '0';
    }
    $groupedCircuits[$grp][] = $row;
}
ksort($groupedCircuits);
$stmt->close();

$allGroups  = array_keys($groupedCircuits);
$totalPages = count($allGroups);
?>

<form id="circuitInspectionForm" enctype="multipart/form-data">
    <input type="hidden" name="master_report_id" value="<?= htmlspecialchars($master_report_id, ENT_QUOTES) ?>">
    <input type="hidden" name="board_id" value="<?= htmlspecialchars($board_id, ENT_QUOTES) ?>">

    <!-- Circuit Cards -->
    <div id="circuitContainer">
        <?php foreach ($allGroups as $idx => $grp): 
      $page    = $idx + 1;
      $display = $page === 1 ? 'block' : 'none';
      foreach ($groupedCircuits[$grp] as $row):
          $cid  = $row['circuit_id'];
          $vals = $circuitData[$cid] ?? [];
  ?>
        <div class="circuit-card" data-page="<?= $page ?>" style="display: <?= $display ?>;">
            <div class="card mb-3">
                <div class="card-header bg-light">
                    <h5>Circuit <?= htmlspecialchars($row['circuit_no'], ENT_QUOTES) ?>:
                        <?= htmlspecialchars($row['circuit_description'], ENT_QUOTES) ?></h5>
                </div>
                <div class="card-body">
                    <div class="row">
                        <!-- Column 1 -->
                        <div class="col-lg-3">
                            <h6 class="text-primary">Continuity</h6>
                            <div class="mb-2">
                                <label>r1 (Ω)</label>
                                <input type="text" name="circuit_results[<?= $cid ?>][r1]" class="form-control form-control-sm"
                                       value="<?= htmlspecialchars($vals['r1'] ?? '', ENT_QUOTES) ?>" required>
                            </div>
                            <div class="mb-2">
                                <label>rn (Ω)</label>
                                <input type="text" name="circuit_results[<?= $cid ?>][rn]" class="form-control form-control-sm"
                                       value="<?= htmlspecialchars($vals['rn'] ?? '', ENT_QUOTES) ?>" required>
                            </div>
                            <div class="mb-2">
                                <label>r2 (Ω)</label>
                                <input type="text" name="circuit_results[<?= $cid ?>][r2]" class="form-control form-control-sm"
                                       value="<?= htmlspecialchars($vals['r2'] ?? '', ENT_QUOTES) ?>" required>
                            </div>
                            <div class="mb-2">
                                <label>R1 + R2 (Ω)</label>
                                <input type="text" name="circuit_results[<?= $cid ?>][r1_r2]" class="form-control form-control-sm"
                                       value="<?= htmlspecialchars($vals['r1_r2'] ?? '', ENT_QUOTES) ?>" required>
                            </div>
                            <div class="mb-2">
                                <label>R2 Continuity (Ω)</label>
                                <input type="text" name="circuit_results[<?= $cid ?>][r2_continuity]" class="form-control form-control-sm"
                                       value="<?= htmlspecialchars($vals['r2_continuity'] ?? '', ENT_QUOTES) ?>" required>
                            </div>
                        </div>
                        <!-- Column 2 -->
                        <div class="col-lg-3">
                            <h6 class="text-primary">Insulation Resistance</h6>
                            <div class="mb-2">
                                <label>P/P (MΩ)</label>
                                <input type="text" name="circuit_results[<?= $cid ?>][pp]" class="form-control form-control-sm"
                                       value="<?= htmlspecialchars($vals['pp'] ?? '', ENT_QUOTES) ?>" required>
                            </div>
                            <div class="mb-2">
                                <label>P/E (MΩ)</label>
                                <input type="text" name="circuit_results[<?= $cid ?>][pe]" class="form-control form-control-sm"
                                       value="<?= htmlspecialchars($vals['pe'] ?? '', ENT_QUOTES) ?>" required>
                            </div>
                        </div>
                        <!-- Column 3 -->
                        <div class="col-lg-3">
                            <h6 class="text-primary">Polarity</h6>
                            <div class="mb-2 form-check">
                                <input type="checkbox" name="circuit_results[<?= $cid ?>][polarity]" class="form-check-input" value="1"
                                       <?= !empty($vals['polarity'])?'checked':'' ?>>
                                <label class="form-check-label">Polarity Confirmed</label>
                            </div>
                            <h6 class="text-primary">Measured Zs</h6>
                            <div class="mb-2">
                                <label>Zs (Ω)</label>
                                <input type="text" name="circuit_results[<?= $cid ?>][zs]" class="form-control form-control-sm"
                                       value="<?= htmlspecialchars($vals['zs'] ?? '', ENT_QUOTES) ?>" required>
                            </div>
                            <h6 class="text-primary">Earth Leakage</h6>
                            <div class="mb-2">
                                <label>Earth Leakage (mA)</label>
                                <input type="text" name="circuit_results[<?= $cid ?>][earth_leakage]" class="form-control form-control-sm"
                                       value="<?= htmlspecialchars($vals['earth_leakage'] ?? '', ENT_QUOTES) ?>" required>
                            </div>
                        </div>
                        <!-- Column 4 -->
                        <div class="col-lg-3">
                            <h6 class="text-primary">RCD Trip Time (ms)</h6>
                            <div class="mb-2">
                                <input type="text" name="circuit_results[<?= $cid ?>][rcd_trip_time]" class="form-control form-control-sm"
                                       value="<?= htmlspecialchars($vals['rcd_trip_time'] ?? '', ENT_QUOTES) ?>" required>
                            </div>
                            <div class="mb-2 form-check">
                                <input type="checkbox" name="circuit_results[<?= $cid ?>][rcd_functional]" class="form-check-input" value="1"
                                       <?= !empty($vals['rcd_functional'])?'checked':'' ?>>
                                <label class="form-check-label">RCD Functional Test</label>
                            </div>
                            <h6 class="text-primary">AFDD Functional</h6>
                            <div class="mb-2 form-check">
                                <input type="checkbox" name="circuit_results[<?= $cid ?>][afdd_functional]" class="form-check-input" value="1"
                                       <?= !empty($vals['afdd_functional'])?'checked':'' ?>>
                                <label class="form-check-label">AFDD Functional Test</label>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php endforeach; endforeach; ?>
    </div>

    <!-- Observation Panels per Group -->
    <div id="observationsContainer">
        <?php foreach ($allGroups as $idx => $grp):
      $page    = $idx + 1;
      $display = $page === 1 ? 'block' : 'none';
      $rawObs  = $observationData[$grp] ?? [];
      $obsList = is_array($rawObs) && count($rawObs) > 0
               ? $rawObs
               : [['fault_code'=>'C1','text'=>'','fi'=>0]];
  ?>
        <div class="observation-panel" data-group="<?= $grp ?>" data-page="<?= $page ?>"
             style="display: <?= $display ?>; margin-bottom:2rem;">
            <div class="obs-rows">

                <?php foreach ($obsList as $i => $obs): ?>
                <div class="card mb-3">
                    <div class="card-header"> Observation #<?= $i ?></div>
                    <div class="card-body">
                        <div class="row g-3 mb-2 obs-row">
                            <div class="col-md-2">
                                <label>Fault Code</label>
                                <select name="observations[<?= $grp ?>][<?= $i ?>][fault_code]"
                                        class="form-select form-select-sm">
                                    <option value="C1" <?= $obs['fault_code']==='C1'?'selected':'' ?>>C1</option>
                                    <option value="C2" <?= $obs['fault_code']==='C2'?'selected':'' ?>>C2</option>
                                    <option value="C13" <?= $obs['fault_code']==='C13'?'selected':'' ?>>C13</option>
                                    <option value="FI" <?= $obs['fault_code']==='FI'?'selected':'' ?>>FI</option>
                                </select>
                            </div>
                            <div class="col-md-8">
                                <label>Observations</label>
                                <div class="d-flex">
                                    <textarea id="observations[<?= $grp ?>][<?= $i ?>][text]" name="observations[<?= $grp ?>][<?= $i ?>][text]" class="form-control form-control-sm"
                                              rows="2"><?= htmlspecialchars($obs['text'], ENT_QUOTES) ?></textarea>
                                    <div class="d-flex flex-column">
                                        <button type="button" class="btn btn-secondary mb-1 ms-4" data-mdb-tooltip-init data-mdb-placement="top" data-mdb-trigger="hover" title="Clear Field"
                                                onClick="clearbox('observations[<?= $grp ?>][<?= $i ?>][text]')">
                                            <i class="fad fa-eraser"></i>
                                        </button>
                                        <?php if($_SESSION['usertype']=="admins"){ ?>
                                        <button type="button" class="btn btn-info mb-1 ms-4" data-mdb-tooltip-init data-mdb-placement="top" data-mdb-trigger="hover" title="View List"
                                                onClick="autofillElec('formComplete','observations[<?= $grp ?>][<?= $i ?>][text]','elecphrases')">
                                            <i class="fad fa-edit"></i>
                                        </button>
                                        <button type="button" class="btn btn-success mb-1 ms-4" data-mdb-tooltip-init data-mdb-placement="top" data-mdb-trigger="hover" title="Save field as new entry"
                                                onClick="savebox('observations[<?= $grp ?>][<?= $i ?>][text]','elecphrases')">
                                            <i class="fad fa-save"></i>
                                        </button>
                                        <?php } else { ?>
                                        <button type="button" class="btn btn-success mb-1 ms-4" onClick="javascript:void(0)"></button>
                                        <button type="button" class="btn btn-info mb-1 ms-4" data-mdb-tooltip-init data-mdb-placement="top" data-mdb-trigger="hover" title="View List"
                                                onClick="autofillElec('formComplete','observations[<?= $grp ?>][<?= $i ?>][text]','elecphrases')">
                                            <i class="fad fa-edit"></i>
                                        </button>
                                        <?php } ?>
                                        <button type="button" class="btn btn-danger btn-info-alt ms-4" data-mdb-tooltip-init data-mdb-placement="top" data-mdb-trigger="hover" title="Reset FIeld"
                                                onClick="resetBox('observations[<?= $grp ?>][<?= $i ?>][text]')">
                                            <i class="fad fa-refresh"></i>
                                        </button>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-2 text-center form-check">
                                <label>FI Y/N</label><br>
                                <input type="checkbox" name="observations[<?= $grp ?>][<?= $i ?>][fi]"
                                       class="form-check-input" value="1" <?= !empty($obs['fi'])?'checked':'' ?>>
                            </div>
                        </div>
                        <div class="row mb-3 img-row">
                            <div class="col-12">
                                <label>Upload Images</label>
                                <div class="row image-uploads" data-group="<?= $grp ?>" data-obs="<?= $i ?>">
                                    <?php for ($j=1; $j<=6; $j++):
                                    $fn   = "{$master_report_id}_{$board_id}_{$grp}_{$i}_{$j}.jpg";
                                    $path = TENANT_DEFER."/images/report_images/{$fn}";
                                    $src  = "images/report_images/{$fn}";
                                    ?>
                                    <div class="col-lg-2 col-md-4 col-6 mb-2">
                                        <div class="imup"
                                             data-service="images/elec_save.php"
                                             data-target="<?= $fn ?>"
                                             data-meta-reportid="<?= $master_report_id ?>"
                                             data-meta-boardid="<?= $board_id ?>"
                                             data-meta-group="<?= $grp ?>"
                                             data-meta-observation="<?= $i ?>"
                                             data-meta-imagenum="<?= $j ?>"
                                             data-crop-ratio="1.3333"
                                             <?php if(file_exists($path)): ?>data-initial-image="<?= $src ?>" <?php endif; ?>>
                                        </div>
                                        <small class="form-text text-muted">Image <?= $j ?></small>
                                    </div>
                                    <?php endfor; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="card-footer"></div>
                </div>
                <?php endforeach; ?>

            </div>
            <button type="button" class="btn btn-secondary btn-sm add-observation" data-group="<?= $grp ?>">
                Add Observation
            </button>
        </div>

        <?php endforeach; ?>
    </div>

    <!-- Pagination Controls -->
    <nav aria-label="Pagination">
        <ul class="pagination justify-content-center">
            <?php for ($p=1; $p<=$totalPages; $p++): ?>
            <li class="page-item <?= $p===1?'active':'' ?>">
                <a class="page-link" href="#" onclick="showPage(<?= $p ?>);return false;"><?= $p ?></a>
            </li>
            <?php endfor; ?>
        </ul>
    </nav>

    <!-- Action Buttons -->
    <div class="d-flex justify-content-between mt-4">
        <button type="button" class="btn btn-success" onclick="saveInspection()">Save Progress</button>
        <button type="button" class="btn btn-info" onclick="markComplete()">Mark Complete</button>
        <button type="button" class="btn btn-danger" onclick="clearAll()">Clear all</button>
    </div>
</form>

<script>
// Pagination (unchanged)
function showPage(pg) {
    document.querySelectorAll('.circuit-card').forEach(c => c.style.display = 'none');
    document.querySelectorAll('.observation-panel').forEach(o => o.style.display = 'none');
    document.querySelectorAll(`.circuit-card[data-page='${pg}']`).forEach(c => c.style.display = 'block');
    const grp = <?= json_encode($allGroups) ?>[pg - 1];
    document.querySelector(`.observation-panel[data-group='${grp}']`).style.display = 'block';
}


// single-observation HTML template (without the <script> placeholders)
// __GRP__ and __IDX__ will be replaced in code
function buildObservationCard(grp, idx) {
    // fault‐code + textarea + FI checkbox
    const obsRow = document.createElement('div');
    obsRow.className = 'card mb-3 obs-card';
    obsRow.innerHTML = `
    <div class="card-header d-flex justify-content-between align-items-center">
      <span>Observation #${idx+1}</span>
      <button type="button" class="btn btn-sm btn-danger remove-observation" data-idx="${idx}">
        <i class="fas fa-trash"></i>
      </button>
    </div>
    <div class="card-body">
      <div class="row g-3 mb-2 obs-row">
        <div class="col-md-2">
          <label>Fault Code</label>
          <select name="observations[${grp}][${idx}][fault_code]" class="form-select form-select-sm">
            <option value="C1">C1</option>
            <option value="C2">C2</option>
            <option value="C13">C13</option>
            <option value="FI">FI</option>
          </select>
        </div>
        <div class="col-md-8">
          <label>Observations</label>
          <textarea name="observations[${grp}][${idx}][text]" class="form-control form-control-sm" rows="2"></textarea>
        </div>
        <div class="col-md-2 text-center form-check">
          <label>FI Y/N</label><br>
          <input type="checkbox" name="observations[${grp}][${idx}][fi]" class="form-check-input" value="1">
        </div>
      </div>
      <div class="row mb-3 img-row">
        <div class="col-12">
          <label>Upload Images</label>
          <div class="row image-uploads" data-group="${grp}" data-obs="${idx}">
            ${[1,2,3,4,5,6].map(i=>`
              <div class="col-lg-2 col-md-4 col-6 mb-2">
                <div class="imup"
                     data-service="images/elec_save.php"
                     data-target="${MASTER_REPORT_ID}_${BOARD_ID}_${grp}_${idx}_${i}.jpg"
                     data-meta-reportid="${MASTER_REPORT_ID}"
                     data-meta-boardid="${BOARD_ID}"
                     data-meta-group="${grp}"
                     data-meta-observation="${idx}"
                     data-meta-imagenum="${i}"
                     data-crop-ratio="1.3333"></div>
                <small class="form-text text-muted">Image ${i}</small>
              </div>`).join('')}
          </div>
        </div>
      </div>
    </div>
    <div class="card-footer"></div>
  `;
    return obsRow;
}

// add-observation
document.querySelectorAll('.add-observation').forEach(btn => {
    btn.addEventListener('click', () => {
        const grp = btn.getAttribute('data-group');
        const panel = document.querySelector(`.observation-panel[data-group='${grp}']`);
        const idx = panel.querySelectorAll('.obs-card').length;
        const card = buildObservationCard(grp, idx);
        // Insert the new card right before the button:
        panel.insertBefore(card, btn);

        // Initialize uploaders inside that card only:
        initializeImageUploaders({
            uploadUrl: 'images/elec_save.php',
            cropRatio: 1,
            removeUrl: 'images/elec_remove.php'
        });
    });
});

// remove-observation
document.addEventListener('click', e => {
    const rm = e.target.closest('.remove-observation');
    if (rm) rm.closest('.obs-card').remove();
});

// Action-button helpers (unchanged)
function disableHiddenPanels() {
    document.querySelectorAll('.observation-panel').forEach(p => {
        if (p.style.display === 'none') {
            p.querySelectorAll('input,select,textarea').forEach(i => i.disabled = true);
        }
    });
}

function saveInspection() {
    disableHiddenPanels();
    saveCircuitStage4('<?= $board_id ?>');
}

function markComplete() {
    disableHiddenPanels();
    markStageComplete4('<?= $board_id ?>');
}

function clearAll() {
    disableHiddenPanels();
    clearStage4('<?= $board_id ?>');
}

// Initialize first view + uploaders
showPage(1);
initializeImageUploaders({
    uploadUrl: 'images/elec_save.php',
    cropRatio: 1,
    removeUrl: 'images/elec_remove.php'
});
</script>