<?php
// save_inspection_test_results.php

// Load config
require_once('../../../' . $_REQUEST['tenant'] . '/config.php');

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success'=>false,'message'=>'Invalid request method.']);
    exit;
}

// 1) Required IDs
$master_report_id = $_POST['master_report_id'] ?? null;
$board_id         = $_POST['board_id']        ?? null;
$clientnumber     = $_POST['clientnumber']    ?? '';

if (!$master_report_id || !$board_id) {
    echo json_encode(['success'=>false,'message'=>'Master report or board ID missing.']);
    exit;
}

// 2) Build circuit_results exactly as before
if (empty($_POST['circuit_results'])) {
    echo json_encode(['success'=>false,'message'=>'No circuit data provided.']);
    exit;
}
$circuit_results = [];
foreach ($_POST['circuit_results'] as $circuit_id => $data) {
    $circuit_results[$circuit_id] = [
        'pe'              => $data['pe']              ?? '-',
        'pp'              => $data['pp']              ?? '-',
        'r1'              => $data['r1']              ?? '-',
        'rn'              => $data['rn']              ?? '-',
        'r2'              => $data['r2']              ?? '-',
        'zs'              => $data['zs']              ?? '-',
        'r1_r2'           => $data['r1_r2']           ?? '-',
        'polarity'        => (isset($data['polarity']) && $data['polarity']==1) ? 1 : 0,
        'earth_leakage'   => $data['earth_leakage']   ?? '-',
        'r2_continuity'   => $data['r2_continuity']   ?? '-',
        'rcd_trip_time'   => $data['rcd_trip_time']   ?? '-',
        'rcd_functional'  => (isset($data['rcd_functional']) && $data['rcd_functional']==1) ? 1 : 0,
        'afdd_functional' => (isset($data['afdd_functional'])&& $data['afdd_functional']==1)?1:0,
    ];
}
$circuit_results_json = json_encode($circuit_results);

// 3) Process Observations: keep **every** row you posted for each circuit,
//    dropping only those rows that stayed at C1 + empty text + fi=0.
$postedObs = $_POST['observations'] ?? [];
$toSaveObs = [];

foreach ($postedObs as $cid => $rows) {
    $filtered = [];
    foreach ($rows as $r) {
        $isDefaultFault = ($r['fault_code']==='C1');
        $isDefaultText  = (trim($r['text'])==='');
        $isDefaultFI    = empty($r['fi']);
        // drop only pure-default rows
        if (!($isDefaultFault && $isDefaultText && $isDefaultFI)) {
            // normalize fi to int
            $r['fi'] = !empty($r['fi']) ? 1 : 0;
            $filtered[] = $r;
        }
    }
    if (count($filtered) > 0) {
        // preserve exactly the rows the user filled
        $toSaveObs[$cid] = array_values($filtered);
    }
}

// JSON‐encode that per-circuit map:
$obsJson = json_encode($toSaveObs, JSON_UNESCAPED_UNICODE);

// 4) Stage status JSON
$stage_status = json_encode([4=>'ongoing'], JSON_UNESCAPED_UNICODE|JSON_UNESCAPED_SLASHES);

// 5) INSERT or UPDATE the single record in elec_report
$is_update = ($_POST['is_update'] ?? '') === 'true';

if ($is_update) {
    $sql = "
      UPDATE elec_report
         SET circuit_results  = ?,
             stage_status     = ?,
             observation_data = ?
       WHERE master_report_id = ?
         AND board_id         = ?
    ";
    $stmt = $con->prepare($sql);
    $stmt->bind_param(
      'sssss',
      $circuit_results_json,
      $stage_status,
      $obsJson,
      $master_report_id,
      $board_id
    );
} else {
    $sql = "
      INSERT INTO elec_report
        (board_id, clientnumber, circuit_results, stage_status, observation_data, status, master_report_id)
      VALUES (?, ?, ?, ?, ?, 'active', ?)
    ";
    $stmt = $con->prepare($sql);
    $stmt->bind_param(
      'isssss',
      $board_id,
      $clientnumber,
      $circuit_results_json,
      $stage_status,
      $obsJson,
      $master_report_id
    );
}

if ($stmt->execute()) {
    echo json_encode([
        'success'   => true,
        'message'   => 'Data saved successfully.',
        'observation_data' => $toSaveObs
    ]);
} else {
    echo json_encode([
        'success' => false,
        'message' => 'Failed to save inspection results.',
        'error'   => $stmt->error
    ]);
}

$stmt->close();
exit;
?>